package com.sun.beans.finder;

import sun.reflect.misc.ReflectUtil;
import java.lang.reflect.Modifier;
import java.lang.reflect.Field;

public final class FieldFinder
{
    public static Field findField(Class<?> clazz, String str) throws NoSuchFieldException {
        if (str == null) {
            throw new IllegalArgumentException("Field name is not set");
        }
        Field field = clazz.getField(str);
        if (!Modifier.isPublic(field.getModifiers())) {
            throw new NoSuchFieldException("Field '" + str + "' is not public");
        }
        Class<Object> declaringClass = field.getDeclaringClass();
        if (!Modifier.isPublic(declaringClass.getModifiers()) || !ReflectUtil.isPackageAccessible(declaringClass)) {
            throw new NoSuchFieldException("Field '" + str + "' is not accessible");
        }
        return field;
    }
    
    public static Field findInstanceField(Class<?> clazz, String str) throws NoSuchFieldException {
        Field field = findField(clazz, str);
        if (Modifier.isStatic(field.getModifiers())) {
            throw new NoSuchFieldException("Field '" + str + "' is static");
        }
        return field;
    }
    
    public static Field findStaticField(Class<?> clazz, String str) throws NoSuchFieldException {
        Field field = findField(clazz, str);
        if (!Modifier.isStatic(field.getModifiers())) {
            throw new NoSuchFieldException("Field '" + str + "' is not static");
        }
        return field;
    }
    
    private FieldFinder() {
    }
}
